@@ -74,6 +74,7 @@ typedef struct
 
     void (*ready) (Scanner *scanner);
     void (*update_devices) (Scanner *scanner, GList *devices);
+    void (*authorize) (Scanner *scanner, const gchar *resource);
     void (*got_page_info) (Scanner *scanner, ScanPageInfo *info);
     void (*got_line) (Scanner *scanner, ScanLine *line);
     void (*scan_failed) (Scanner *scanner, GError *error);
@@ -87,6 +88,8 @@ Scanner *scanner_new (void);
 
 void scanner_start (Scanner *scanner);
 
+void scanner_authorize (Scanner *scanner, const gchar *username, const gchar *password);
+
 void scanner_scan (Scanner *scanner, const char *device, const char *source,
                    gint dpi, ScanMode scan_mode, gint depth, gboolean multi_page);
 
